@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 90 $
+# Revision: $Rev: 692 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -18,7 +18,7 @@
 #    You should have received a copy of the GNU General Public License     #
 #    along with this program; if not, write to the                         #
 #    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
+#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
 ############################################################################
 
 #-- imports --------------------------------------------------------------------
@@ -95,7 +95,7 @@ class URIListDrag(QUriDrag):
     def __init__(self, uris, dragSource=None, name=None):
         QUriDrag.__init__(self, uris, dragSource, name)
         log.setLevel(pref['logLevel'])
-
+        
 
     def decode(cls, e, img):
         """decodes an image from the URI and returns a QImage instance"""
@@ -105,6 +105,9 @@ class URIListDrag(QUriDrag):
         # get contents (of the form: file:/home/...)
         lines = QStringList()
         if (not QUriDrag.decodeLocalFiles(e, lines)): return False
+        if len(lines) == 0:
+            cls.log.warning("Loading remote files not yet supported")
+            return False
         filename = unicode(lines[0])    # convert QString -> unicode
 
         # load data
