@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 761 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -142,6 +142,7 @@ class ListViewRecord(QListView):
         self.setRootIsDecorated(group != None)
         # shrink column 0 to minimum width
         self.setColumnWidth(0, 0)
+
         # restore previous current item
         if (self.items.has_key(tmpCurrentItem)):
             self.setCurrentItem(tmpCurrentItem)
@@ -159,10 +160,14 @@ class ListViewRecord(QListView):
                 # this *is* an int, because of the Qt object its contained in
                 ymd = Date2YMD(int(value))
                 value = "%02d-%02d-%04d"%(ymd[2], ymd[1], ymd[0])
-                
+
+            # an empty key causes a seg-fault
+            if (value == ''):
+                value = '<unset>'
+
             # all other fields: if no parent exists yet
             if (not self.groupMap.has_key(value)):
-                self.log.debug("Creating parent group %s", value)
+                self.log.debug("Creating new group: '%s'", value)
                 parent = cls_ListViewItem(self, value, "(1)")
                 parent.setSelectable(False)
                 self.groupMap[value] = parent
@@ -170,7 +175,7 @@ class ListViewRecord(QListView):
             # update child count
             else:
                 parent = self.groupMap[value]
-                oldVal = unicode(parent.text(1)) 
+                oldVal = unicode(parent.text(1))
                 parent.setText(1, "(%d)"%(int(oldVal[1:-1])+1,))
 
             # return new (or old) parent
