@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 748 $
+# Revision: $Rev: 759 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -354,7 +354,7 @@ class DropLabel(QLabel):
 
 
 
-class PicturePreview(PicturePreviewBase, QDockWindow):
+class PicturePreview(PicturePreviewBase):
     """displays a picture and scales it appropriately"""
     def __init__(self, dirname, parent=None, name=None, fl=0):
         PicturePreviewBase.__init__(self, parent, name, fl)
@@ -370,6 +370,7 @@ class PicturePreview(PicturePreviewBase, QDockWindow):
         self.pix = QPixmap()            # pixmap
         self.labelImage = DropLabel(self) # label with drop support
         self.copyImg = None             # when copying images
+        self.enableZoom = True          # enable click on image for large view
 
         self.recycle_pix = QPixmap()
         self.recycle_pix.loadFromData(recycle_bin_data, "PNG")
@@ -387,11 +388,12 @@ class PicturePreview(PicturePreviewBase, QDockWindow):
         gridLayoutLabel = QGridLayout( self, 1,1 )
         gridLayoutLabel.addWidget( self.labelImage, 0,0 )
 
+        self.setCaption("picture")
+
         # connect signal to detect dropped images
         self.connect(self.labelImage, PYSIGNAL("imageDropped"), self.onImageDropped)
 
 
-
     #-- event handlers ---------------------------------------------------------
     def resizeEvent(self, e):
         """called when widget is resized"""
@@ -423,7 +425,7 @@ class PicturePreview(PicturePreviewBase, QDockWindow):
             return
             
         # spawn unscaled picture
-        if (self.img != None):
+        if ((self.img != None) and (self.enableZoom)):
             dlg = PictureDialog(self.img, modal=False)
             dlg.exec_loop()
 
@@ -566,6 +568,19 @@ class PicturePreview(PicturePreviewBase, QDockWindow):
 
 
     #-- interface --------------------------------------------------------------
+    def setEnableZoom(self, value):
+        """enables /disables picture preview"""
+        self.enableZoom = value
+
+
+    def imageSize(self):
+        """returns QSize of the embedded image, None otherwise"""
+        if (self.img):
+            return self.img.size()
+        else:
+            return None
+        
+
     def resizeImage(self):
         """puts the image in a label on the screen at the correct size"""
         if (self.img != None):
@@ -844,3 +859,4 @@ if (__name__ == "__main__"):
     tmp = w.getRecord()
     print "len embedded: ",len(tmp['embeddedImage'])
     print "picture:  ",tmp['picture']
+
