@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 760 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -38,7 +38,7 @@ import defaults
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 760 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -387,6 +387,12 @@ scripts = %(scripts)s
 defaultScript = %(defaultScript)s
 
 
+# export holds a list of available export scripts and templates that are
+# available through the export dialog.
+# 
+export = %(export)s
+
+
 #-- EOF --
 """
 
@@ -607,6 +613,39 @@ class _Settings1(_Settings0):
             self['filenamePrefix'] = result
                 
         
+class _Settings2(_Settings1):
+    """extends previous settings object by a new log class
+
+    This was introduced with log format version 0.2.
+    """
+    def __init__(self):
+        super(_Settings2, self).__init__()
+
+    def selfUpdate(self, toDict, fromDict):
+        super(_Settings2, self).selfUpdate(toDict, fromDict)
+
+        # add new log class
+        self['version'] = '0.2'
+        self['logLevel']['PictureDockWindow'] = logging.DEBUG
+        self['logLevel']['ExportDialog'] = logging.DEBUG
+
+        # add export settings
+        self['export'] = {u'LaTex /PDF': u'pytex.py templates/merkosh_pdf_template.tex /tmp/merkosh_pdf.tex; pdflatex /tmp/merkosh_pdf.tex', }
+        
+
+    def asText(self):
+        """returns a dict which interpolates configText"""
+        # call ancestor
+        defs = super(_Settings2, self).asText()
+
+        # interpolate export settings
+        for key in ['export']:
+            defs[key] = pformat(self[key])
+
+        # return result
+        return defs
+        
+
 
 #-- main class for config format -----------------------------------------------
 # If the configuration format needs to be changed and in order to keep
@@ -618,7 +657,7 @@ class _Settings1(_Settings0):
 # a way that when calling the parent's asText() or update() method the
 # interface to the old-style configuration is maintained and the return
 # value reflects the current state of the configuration.
-class _Settings(_Settings1):
+class _Settings(_Settings2):
     """encapsulates loading, updating and saving of global program defaults
 
     Compared to the _Pref class, this contains the global, cross-class
@@ -768,3 +807,4 @@ if (__name__ == '__main__'):
     a = Settings()
     a.save()
     b = getPreferences()
+<
