@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 761 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -48,7 +48,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("moviefly  $Rev: 692 $ (c) by Uwe Mayer")
+log.info("moviefly  $Rev: 761 $ (c) by Uwe Mayer")
 
 
 #-- own imports --
@@ -211,6 +211,8 @@ class LMCMain(LMCWidgetBase):
             else:
                 self.fileOpen(infile)
 
+        # maximize main window
+        self.showMaximized()
 
 
     #-- slot implementations ---------------------------------------------------
@@ -300,6 +302,7 @@ class LMCMain(LMCWidgetBase):
         if (self.recordActionsEnabled):
             self._disableRecordActions()
         self._disableFileActions()
+        self._disableViewActions()
 
         self._querySaveOnDirty()
 
@@ -463,6 +466,7 @@ class LMCMain(LMCWidgetBase):
 
         # connect slots
         self._enableFileActions()
+        self._enableViewActions()
         self.connect(self.centralWidget(), PYSIGNAL("currentChanged"), self.currentChanged)
         
 
@@ -557,6 +561,7 @@ class LMCMain(LMCWidgetBase):
 
         # enable rest of the actions
         self._enableFileActions()
+        self._enableViewActions()
 
 
     def fileProperties(self):
@@ -931,6 +936,10 @@ class LMCMain(LMCWidgetBase):
         self.centralWidget().changeNumber(mode, number)
         
 
+    def togglePicturePreview(self):
+        """called when toggling picture preview"""
+        self.centralWidget().togglePicturePreview()
+        
 
     #-- helper methods ---------------------------------------------------------
     def _updateRecentFiles(self):
@@ -1008,6 +1017,24 @@ class LMCMain(LMCWidgetBase):
         self.log.info("Using file format: %s", cls)
         return (cls, filename)
         
+
+    def _enableViewActions(self):
+        """enable View actions"""
+        self.log.debug("Enabling view actions""")
+
+        self.connect(self.togglePicturePreviewAction, SIGNAL("toggled(bool)"), self.togglePicturePreview)
+        self.togglePicturePreviewAction.setEnabled(True)
+
+
+
+    def _disableViewActions(self):
+        """disable View actions"""
+        self.log.debug("Disabling view actions""")
+
+        self.togglePicturePreviewAction.setEnabled(False)
+        self.disconnect(self.togglePicturePreviewAction, SIGNAL("toggled(bool)"), self.togglePicturePreview)
+
+        
         
 
     def _enableFileActions(self):
@@ -1246,7 +1273,7 @@ Synopsis: lmc.py [-h|--help] [<input-file>]
 elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
     print "Moviefly  (c) by Uwe Mayer"
     print "Version:  %s"%version
-    print "Revision: $Rev: 692 $"
+    print "Revision: $Rev: 761 $"
     print 
     sys.exit()
     
